@@ -39,27 +39,27 @@
 
 #include <vector>
 
-#include "SharedHandle.h"
-
 namespace aria2 {
 
 class BitfieldMan {
 private:
-  size_t blockLength_;
-  uint64_t totalLength_;
-  size_t bitfieldLength_;
-  size_t blocks_;
-  bool filterEnabled_;
+  int64_t totalLength_;
+  int64_t cachedCompletedLength_;
+  int64_t cachedFilteredCompletedLength_;
+  int64_t cachedFilteredTotalLength_;
+
   unsigned char* bitfield_;
   unsigned char* useBitfield_;
   unsigned char* filterBitfield_;
 
-  // for caching
+  size_t bitfieldLength_;
   size_t cachedNumMissingBlock_;
   size_t cachedNumFilteredBlock_;
-  uint64_t cachedCompletedLength_;
-  uint64_t cachedFilteredCompletedLength_;
-  uint64_t cachedFilteredTotalLength_;
+  size_t blocks_;
+
+  int32_t blockLength_;
+
+  bool filterEnabled_;
 
   bool setBitInternal(unsigned char* bitfield, size_t index, bool on);
   bool setFilterBit(size_t index);
@@ -67,11 +67,12 @@ private:
   size_t getStartIndex(size_t index) const;
   size_t getEndIndex(size_t index) const;
 
-  uint64_t getCompletedLength(bool useFilter) const;
+  int64_t getCompletedLength(bool useFilter) const;
 
   // If filterBitfield_ is 0, allocate bitfieldLength_ bytes to it and
   // set 0 to all bytes.
   void ensureFilterBitfield();
+
 public:
   // [startIndex, endIndex)
   struct Range {
@@ -80,26 +81,24 @@ public:
     Range(size_t startIndex = 0, size_t endIndex = 0);
     size_t getSize() const;
     size_t getMidIndex() const;
-    bool operator<(const Range& range) const;    
+    bool operator<(const Range& range) const;
     bool operator==(const Range& range) const;
   };
+
 public:
-  BitfieldMan(size_t blockLength, uint64_t totalLength);
+  BitfieldMan(int32_t blockLength, int64_t totalLength);
   BitfieldMan(const BitfieldMan& bitfieldMan);
   ~BitfieldMan();
 
   BitfieldMan& operator=(const BitfieldMan& bitfieldMan);
 
-  size_t getBlockLength() const
-  {
-    return blockLength_;
-  }
+  int32_t getBlockLength() const { return blockLength_; }
 
-  size_t getLastBlockLength() const;
+  int32_t getLastBlockLength() const;
 
-  size_t getBlockLength(size_t index) const;
+  int32_t getBlockLength(size_t index) const;
 
-  uint64_t getTotalLength() const { return totalLength_; }
+  int64_t getTotalLength() const { return totalLength_; }
 
   // Returns true iff there is a bit index which is set in bitfield_,
   // but not set in this object.
@@ -129,11 +128,9 @@ public:
   // if such bit index is found. Otherwise returns false.
   //
   // affected by filter
-  bool getSparseMissingUnusedIndex
-  (size_t& index,
-   size_t minSplitSize,
-   const unsigned char* ignoreBitfield,
-   size_t ignoreBitfieldLength) const;
+  bool getSparseMissingUnusedIndex(size_t& index, int32_t minSplitSize,
+                                   const unsigned char* ignoreBitfield,
+                                   size_t ignoreBitfieldLength) const;
 
   // Stores missing bit index to index. This function first try to
   // select smallest index starting offsetIndex in the order:
@@ -149,13 +146,10 @@ public:
   // result.
   //
   // affected by filter
-  bool getGeomMissingUnusedIndex
-  (size_t& index,
-   size_t minSplitSize,
-   const unsigned char* ignoreBitfield,
-   size_t ignoreBitfieldLength,
-   double base,
-   size_t offsetIndex) const;
+  bool getGeomMissingUnusedIndex(size_t& index, int32_t minSplitSize,
+                                 const unsigned char* ignoreBitfield,
+                                 size_t ignoreBitfieldLength, double base,
+                                 size_t offsetIndex) const;
 
   // Stores missing bit index to index. This function selects smallest
   // index of missing piece, considering minSplitSize.  Set bits in
@@ -163,11 +157,9 @@ public:
   // found. Otherwise returns false.
   //
   // affected by filter
-  bool getInorderMissingUnusedIndex
-  (size_t& index,
-   size_t minSplitSize,
-   const unsigned char* ignoreBitfield,
-   size_t ignoreBitfieldLength) const;
+  bool getInorderMissingUnusedIndex(size_t& index, int32_t minSplitSize,
+                                    const unsigned char* ignoreBitfield,
+                                    size_t ignoreBitfieldLength) const;
 
   // affected by filter
   bool getAllMissingIndexes(unsigned char* misbitfield, size_t mislen) const;
@@ -200,35 +192,23 @@ public:
   bool isAllBitSet() const;
 
   bool isAllFilterBitSet() const;
+  // Returns true if index bit is set in filterBitfield_.  If
+  // filterBitfield_ is NULL, returns false.
+  bool isFilterBitSet(size_t index) const;
 
-  const unsigned char* getBitfield() const
-  {
-    return bitfield_;
-  }
+  const unsigned char* getBitfield() const { return bitfield_; }
 
-  size_t getBitfieldLength() const
-  {
-    return bitfieldLength_;
-  }
+  size_t getBitfieldLength() const { return bitfieldLength_; }
 
   // affected by filter
-  size_t countFilteredBlock() const
-  {
-    return cachedNumFilteredBlock_;
-  }
+  size_t countFilteredBlock() const { return cachedNumFilteredBlock_; }
 
-  size_t countBlock() const
-  {
-    return blocks_;
-  }
+  size_t countBlock() const { return blocks_; }
 
   // affected by filter
   size_t countFilteredBlockNow() const;
 
-  size_t getMaxIndex() const
-  {
-    return blocks_-1;
-  }
+  size_t getMaxIndex() const { return blocks_ - 1; }
 
   void setBitfield(const unsigned char* bitfield, size_t bitfieldLength);
 
@@ -238,45 +218,36 @@ public:
   void clearAllUseBit();
   void setAllUseBit();
 
-  void addFilter(uint64_t offset, uint64_t length);
-  void removeFilter(uint64_t offset, uint64_t length);
+  void addFilter(int64_t offset, int64_t length);
+  void removeFilter(int64_t offset, int64_t length);
   // Add filter not in the range of [offset, offset+length) bytes
-  void addNotFilter(uint64_t offset, uint64_t length);
+  void addNotFilter(int64_t offset, int64_t length);
 
   // Clears filter and disables filter
   void clearFilter();
-  
+
   void enableFilter();
   void disableFilter();
-  bool isFilterEnabled() const
-  {
-    return filterEnabled_;
-  }
+  bool isFilterEnabled() const { return filterEnabled_; }
 
   // affected by filter
-  uint64_t getFilteredTotalLength() const
-  {
-    return cachedFilteredTotalLength_;
-  }
+  int64_t getFilteredTotalLength() const { return cachedFilteredTotalLength_; }
 
   // affected by filter
-  uint64_t getFilteredTotalLengthNow() const;
+  int64_t getFilteredTotalLengthNow() const;
 
-  uint64_t getCompletedLength() const
-  {
-    return cachedCompletedLength_;
-  }
+  int64_t getCompletedLength() const { return cachedCompletedLength_; }
 
-  uint64_t getCompletedLengthNow() const;
+  int64_t getCompletedLengthNow() const;
 
   // affected by filter
-  uint64_t getFilteredCompletedLength() const
+  int64_t getFilteredCompletedLength() const
   {
     return cachedFilteredCompletedLength_;
   }
 
   // affected by filter
-  uint64_t getFilteredCompletedLengthNow() const;
+  int64_t getFilteredCompletedLengthNow() const;
 
   void updateCache();
 
@@ -286,18 +257,15 @@ public:
 
   void setBitRange(size_t startIndex, size_t endIndex);
 
-  bool isBitSetOffsetRange(uint64_t offset, uint64_t length) const;
+  bool isBitSetOffsetRange(int64_t offset, int64_t length) const;
 
   // Returns completed length in bytes in range [offset,
   // offset+length). This function will not affected by filter.
-  uint64_t getOffsetCompletedLength(uint64_t offset, uint64_t length) const;
+  int64_t getOffsetCompletedLength(int64_t offset, int64_t length) const;
 
-  uint64_t getMissingUnusedLength(size_t startingIndex) const;
+  int64_t getMissingUnusedLength(size_t startingIndex) const;
 
-  const unsigned char* getFilterBitfield() const
-  {
-    return filterBitfield_;
-  }
+  const unsigned char* getFilterBitfield() const { return filterBitfield_; }
 };
 
 } // namespace aria2
