@@ -45,29 +45,34 @@
 
 namespace aria2 {
 
-BtSeederStateChoke::BtSeederStateChoke()
-  : round_(0),
-    lastRound_(0)
-{}
+BtSeederStateChoke::BtSeederStateChoke() : round_(0), lastRound_(Timer::zero())
+{
+}
 
 BtSeederStateChoke::~BtSeederStateChoke() {}
 
-BtSeederStateChoke::PeerEntry::PeerEntry
-(const SharedHandle<Peer>& peer):
-  peer_(peer),
-  outstandingUpload_(peer->countOutstandingUpload()),
-  lastAmUnchoking_(peer->getLastAmUnchoking()),
-  recentUnchoking_(lastAmUnchoking_.difference(global::wallclock()) < TIME_FRAME),
-  uploadSpeed_(peer->calculateUploadSpeed())
-{}
+namespace {
+constexpr auto TIME_FRAME = 20_s;
+} // namespace
+
+BtSeederStateChoke::PeerEntry::PeerEntry(const std::shared_ptr<Peer>& peer)
+    : peer_(peer),
+      outstandingUpload_(peer->countOutstandingUpload()),
+      lastAmUnchoking_(peer->getLastAmUnchoking()),
+      recentUnchoking_(lastAmUnchoking_.difference(global::wallclock()) <
+                       TIME_FRAME),
+      uploadSpeed_(peer->calculateUploadSpeed())
+{
+}
 
 BtSeederStateChoke::PeerEntry::PeerEntry(const PeerEntry& c)
-  : peer_(c.peer_),
-    outstandingUpload_(c.outstandingUpload_),
-    lastAmUnchoking_(c.lastAmUnchoking_),
-    recentUnchoking_(c.recentUnchoking_),
-    uploadSpeed_(c.uploadSpeed_)
-{}
+    : peer_(c.peer_),
+      outstandingUpload_(c.outstandingUpload_),
+      lastAmUnchoking_(c.lastAmUnchoking_),
+      recentUnchoking_(c.recentUnchoking_),
+      uploadSpeed_(c.uploadSpeed_)
+{
+}
 
 BtSeederStateChoke::PeerEntry::~PeerEntry() {}
 
@@ -81,10 +86,10 @@ void BtSeederStateChoke::PeerEntry::swap(PeerEntry& c)
   swap(uploadSpeed_, c.uploadSpeed_);
 }
 
-BtSeederStateChoke::PeerEntry& BtSeederStateChoke::PeerEntry::operator=
-(const PeerEntry& c)
+BtSeederStateChoke::PeerEntry& BtSeederStateChoke::PeerEntry::
+operator=(const PeerEntry& c)
 {
-  if(this != &c) {
+  if (this != &c) {
     peer_ = c.peer_;
     outstandingUpload_ = c.outstandingUpload_;
     lastAmUnchoking_ = c.lastAmUnchoking_;
@@ -94,20 +99,22 @@ BtSeederStateChoke::PeerEntry& BtSeederStateChoke::PeerEntry::operator=
   return *this;
 }
 
-bool
-BtSeederStateChoke::PeerEntry::operator<(const PeerEntry& rhs) const
+bool BtSeederStateChoke::PeerEntry::operator<(const PeerEntry& rhs) const
 {
-  if(this->outstandingUpload_ && !rhs.outstandingUpload_) {
+  if (this->outstandingUpload_ && !rhs.outstandingUpload_) {
     return true;
-  } else if(!this->outstandingUpload_ && rhs.outstandingUpload_) {
+  }
+  else if (!this->outstandingUpload_ && rhs.outstandingUpload_) {
     return false;
   }
-  if(this->recentUnchoking_ &&
-     (this->lastAmUnchoking_ > rhs.lastAmUnchoking_)) {
+  if (this->recentUnchoking_ &&
+      (this->lastAmUnchoking_ > rhs.lastAmUnchoking_)) {
     return true;
-  } else if(rhs.recentUnchoking_) {
+  }
+  else if (rhs.recentUnchoking_) {
     return false;
-  } else {
+  }
+  else {
     return this->uploadSpeed_ > rhs.uploadSpeed_;
   }
 }
@@ -117,78 +124,52 @@ void BtSeederStateChoke::PeerEntry::disableOptUnchoking()
   peer_->optUnchoking(false);
 }
 
-bool BtSeederStateChoke::NotInterestedPeer::operator()
-  (const PeerEntry& peerEntry) const
-{
-  return !peerEntry.getPeer()->peerInterested();
-}
-
-void BtSeederStateChoke::unchoke
-(std::vector<BtSeederStateChoke::PeerEntry>& peers)
+void BtSeederStateChoke::unchoke(
+    std::vector<BtSeederStateChoke::PeerEntry>& peers)
 {
   int count = (round_ == 2) ? 4 : 3;
 
-  std::sort(peers.begin(), peers.end());
+  std::sort(std::begin(peers), std::end(peers));
 
-  std::vector<PeerEntry>::iterator r = peers.begin();
-  for(std::vector<PeerEntry>::iterator eoi = peers.end();
-      r != eoi && count; ++r, --count) {
+  auto r = std::begin(peers);
+  for (; r != std::end(peers) && count; ++r, --count) {
     (*r).getPeer()->chokingRequired(false);
-    A2_LOG_INFO(fmt("RU: %s, ulspd=%u",
-                    (*r).getPeer()->getIPAddress().c_str(),
+    A2_LOG_INFO(fmt("RU: %s, ulspd=%d", (*r).getPeer()->getIPAddress().c_str(),
                     (*r).getUploadSpeed()));
   }
 
-  if(round_ < 2) {
-    std::for_each(peers.begin(), peers.end(),
-                  std::mem_fun_ref(&PeerEntry::disableOptUnchoking));
-    if(r != peers.end()) {
-      std::random_shuffle(r, peers.end(),
-                          *(SimpleRandomizer::getInstance().get()));
+  if (round_ < 2) {
+    std::for_each(std::begin(peers), std::end(peers),
+                  std::mem_fn(&PeerEntry::disableOptUnchoking));
+    if (r != std::end(peers)) {
+      std::shuffle(r, std::end(peers), *SimpleRandomizer::getInstance());
       (*r).getPeer()->optUnchoking(true);
       A2_LOG_INFO(fmt("POU: %s", (*r).getPeer()->getIPAddress().c_str()));
     }
   }
 }
 
-namespace {
-class ChokingRequired {
-public:
-  void operator()(const SharedHandle<Peer>& peer) const
-  {
-    peer->chokingRequired(true);
-  }
-};
-} // namespace
-
-void
-BtSeederStateChoke::executeChoke
-(const std::vector<SharedHandle<Peer> >& peerSet)
+void BtSeederStateChoke::executeChoke(const PeerSet& peerSet)
 {
   A2_LOG_INFO(fmt("Seeder state, %d choke round started", round_));
   lastRound_ = global::wallclock();
 
   std::vector<PeerEntry> peerEntries;
-
-  std::for_each(peerSet.begin(), peerSet.end(), ChokingRequired());
-
-  std::transform(peerSet.begin(), peerSet.end(),
-                 std::back_inserter(peerEntries), GenPeerEntry());
-              
-  peerEntries.erase(std::remove_if(peerEntries.begin(), peerEntries.end(),
-                                   NotInterestedPeer()),
-                    peerEntries.end());
+  for (const auto& p : peerSet) {
+    if (p->isActive() && p->peerInterested()) {
+      p->chokingRequired(true);
+      peerEntries.push_back(PeerEntry(p));
+    }
+  }
 
   unchoke(peerEntries);
-  
-  if(++round_ == 3) {
+
+  if (++round_ == 3) {
     round_ = 0;
   }
 }
 
-void swap
-(BtSeederStateChoke::PeerEntry& a,
- BtSeederStateChoke::PeerEntry& b)
+void swap(BtSeederStateChoke::PeerEntry& a, BtSeederStateChoke::PeerEntry& b)
 {
   a.swap(b);
 }
