@@ -39,28 +39,25 @@
 
 namespace aria2 {
 
-class BtUnchokeMessage;
-
-typedef SharedHandle<BtUnchokeMessage> BtUnchokeMessageHandle;
-
 class BtUnchokeMessage : public ZeroBtMessage {
 private:
   static const size_t MESSAGE_LENGTH = 5;
+
 public:
   BtUnchokeMessage();
 
   static const uint8_t ID = 1;
 
-  static const std::string NAME;
+  static const char NAME[];
 
-  static SharedHandle<BtUnchokeMessage> create
-  (const unsigned char* data, size_t dataLength);
+  static std::unique_ptr<BtUnchokeMessage> create(const unsigned char* data,
+                                                  size_t dataLength);
 
-  virtual void doReceivedAction();
+  virtual void doReceivedAction() CXX11_OVERRIDE;
 
-  virtual bool sendPredicate() const;
+  virtual bool sendPredicate() const CXX11_OVERRIDE;
 
-  virtual void onSendComplete();
+  virtual std::unique_ptr<ProgressUpdate> getProgressUpdate() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
