@@ -80,57 +80,59 @@ DHTSetup::DHTSetup() {}
 
 DHTSetup::~DHTSetup() {}
 
-std::vector<std::unique_ptr<Command>> DHTSetup::setup
-(DownloadEngine* e, int family)
+std::pair<std::vector<std::unique_ptr<Command>>,
+          std::vector<std::unique_ptr<Command>>>
+DHTSetup::setup(DownloadEngine* e, int family)
 {
-  std::vector<std::unique_ptr<Command> > tempCommands;
-  if((family != AF_INET && family != AF_INET6) ||
-     (family == AF_INET && DHTRegistry::isInitialized()) ||
-     (family == AF_INET6 && DHTRegistry::isInitialized6())) {
-    return tempCommands;
+  std::vector<std::unique_ptr<Command>> tempCommands;
+  std::vector<std::unique_ptr<Command>> tempRoutineCommands;
+  if ((family != AF_INET && family != AF_INET6) ||
+      (family == AF_INET && DHTRegistry::isInitialized()) ||
+      (family == AF_INET6 && DHTRegistry::isInitialized6())) {
+    return {};
   }
   try {
     // load routing table and localnode id here
     std::shared_ptr<DHTNode> localNode;
 
     DHTRoutingTableDeserializer deserializer(family);
-    const std::string& dhtFile =
-      e->getOption()->get(family == AF_INET?PREF_DHT_FILE_PATH:
-                          PREF_DHT_FILE_PATH6);
+    const std::string& dhtFile = e->getOption()->get(
+        family == AF_INET ? PREF_DHT_FILE_PATH : PREF_DHT_FILE_PATH6);
     try {
       deserializer.deserialize(dhtFile);
       localNode = deserializer.getLocalNode();
-    } catch(RecoverableException& e) {
-      A2_LOG_ERROR_EX
-        (fmt("Exception caught while loading DHT routing table from %s",
-             dhtFile.c_str()),
-         e);
     }
-    if(!localNode) {
-      localNode.reset(new DHTNode());
+    catch (RecoverableException& e) {
+      A2_LOG_ERROR_EX(
+          fmt("Exception caught while loading DHT routing table from %s",
+              dhtFile.c_str()),
+          e);
+    }
+    if (!localNode) {
+      localNode = std::make_shared<DHTNode>();
     }
 
     uint16_t port;
     auto connection = make_unique<DHTConnectionImpl>(family);
     {
       port = e->getBtRegistry()->getUdpPort();
-      const std::string& addr =
-        e->getOption()->get(family == AF_INET ? PREF_DHT_LISTEN_ADDR:
-                            PREF_DHT_LISTEN_ADDR6);
+      const std::string& addr = e->getOption()->get(
+          family == AF_INET ? PREF_DHT_LISTEN_ADDR : PREF_DHT_LISTEN_ADDR6);
       // If UDP port is already used, use the same port
       // number. Normally IPv4 port is available, then IPv6 port is
       // (especially for port >= 1024). We don't loose much by doing
       // this. We did the same thing in TCP socket. See BtSetup.cc.
       bool rv;
-      if(port == 0) {
-        SegList<int> sgl;
-        util::parseIntSegments(sgl, e->getOption()->get(PREF_DHT_LISTEN_PORT));
+      if (port == 0) {
+        auto sgl =
+            util::parseIntSegments(e->getOption()->get(PREF_DHT_LISTEN_PORT));
         sgl.normalize();
         rv = connection->bind(port, addr, sgl);
-      } else {
+      }
+      else {
         rv = connection->bind(port, addr);
       }
-      if(!rv) {
+      if (!rv) {
         throw DL_ABORT_EX("Error occurred while binding UDP port for DHT");
       }
       localNode->setPort(port);
@@ -148,13 +150,13 @@ std::vector<std::unique_ptr<Command>> DHTSetup::setup
     auto tokenTracker = make_unique<DHTTokenTracker>();
     // For now, UDPTrackerClient was enabled along with DHT
     auto udpTrackerClient = std::make_shared<UDPTrackerClient>();
-    const time_t messageTimeout =
-      e->getOption()->getAsInt(PREF_DHT_MESSAGE_TIMEOUT);
+    const auto messageTimeout =
+        e->getOption()->getAsInt(PREF_DHT_MESSAGE_TIMEOUT);
     // wiring up
     tracker->setRoutingTable(routingTable.get());
     tracker->setMessageFactory(factory.get());
 
-    dispatcher->setTimeout(messageTimeout);
+    dispatcher->setTimeout(std::chrono::seconds(messageTimeout));
 
     receiver->setMessageFactory(factory.get());
     receiver->setRoutingTable(routingTable.get());
@@ -164,7 +166,7 @@ std::vector<std::unique_ptr<Command>> DHTSetup::setup
     taskFactory->setMessageDispatcher(dispatcher.get());
     taskFactory->setMessageFactory(factory.get());
     taskFactory->setTaskQueue(taskQueue.get());
-    taskFactory->setTimeout(messageTimeout);
+    taskFactory->setTimeout(std::chrono::seconds(messageTimeout));
 
     routingTable->setTaskQueue(taskQueue.get());
     routingTable->setTaskFactory(taskFactory.get());
@@ -179,20 +181,20 @@ std::vector<std::unique_ptr<Command>> DHTSetup::setup
     factory->setTokenTracker(tokenTracker.get());
     factory->setLocalNode(localNode);
 
-    const Pref* prefEntryPointHost =
-      family == AF_INET?PREF_DHT_ENTRY_POINT_HOST:PREF_DHT_ENTRY_POINT_HOST6;
-    if(!e->getOption()->get(prefEntryPointHost).empty()) {
+    PrefPtr prefEntryPointHost = family == AF_INET ? PREF_DHT_ENTRY_POINT_HOST
+                                                   : PREF_DHT_ENTRY_POINT_HOST6;
+    if (!e->getOption()->get(prefEntryPointHost).empty()) {
       {
-        const Pref* prefEntryPointPort =
-          family == AF_INET?PREF_DHT_ENTRY_POINT_PORT:
-          PREF_DHT_ENTRY_POINT_PORT6;
-        std::pair<std::string, uint16_t> addr
-          (e->getOption()->get(prefEntryPointHost),
-           e->getOption()->getAsInt(prefEntryPointPort));
+        PrefPtr prefEntryPointPort = family == AF_INET
+                                         ? PREF_DHT_ENTRY_POINT_PORT
+                                         : PREF_DHT_ENTRY_POINT_PORT6;
+        std::pair<std::string, uint16_t> addr(
+            e->getOption()->get(prefEntryPointHost),
+            e->getOption()->getAsInt(prefEntryPointPort));
         std::vector<std::pair<std::string, uint16_t>> entryPoints;
         entryPoints.push_back(addr);
-        auto command = make_unique<DHTEntryPointNameResolveCommand>
-          (e->newCUID(), e, entryPoints);
+        auto command = make_unique<DHTEntryPointNameResolveCommand>(
+            e->newCUID(), e, entryPoints);
         command->setBootstrapEnabled(true);
         command->setTaskQueue(taskQueue.get());
         command->setTaskFactory(taskFactory.get());
@@ -200,7 +202,8 @@ std::vector<std::unique_ptr<Command>> DHTSetup::setup
         command->setLocalNode(localNode);
         tempCommands.push_back(std::move(command));
       }
-    } else {
+    }
+    else {
       A2_LOG_INFO("No DHT entry point specified.");
     }
     {
@@ -211,91 +214,96 @@ std::vector<std::unique_ptr<Command>> DHTSetup::setup
       command->setReadCheckSocket(connection->getSocket());
       command->setConnection(std::move(connection));
       command->setUDPTrackerClient(udpTrackerClient);
-      tempCommands.push_back(std::move(command));
+      tempRoutineCommands.push_back(std::move(command));
     }
     {
-      auto command = make_unique<DHTTokenUpdateCommand>
-        (e->newCUID(), e, DHT_TOKEN_UPDATE_INTERVAL);
+      auto command = make_unique<DHTTokenUpdateCommand>(
+          e->newCUID(), e, DHT_TOKEN_UPDATE_INTERVAL);
       command->setTokenTracker(tokenTracker.get());
       tempCommands.push_back(std::move(command));
     }
     {
-      auto command = make_unique<DHTBucketRefreshCommand>
-        (e->newCUID(), e, DHT_BUCKET_REFRESH_CHECK_INTERVAL);
+      auto command = make_unique<DHTBucketRefreshCommand>(
+          e->newCUID(), e, DHT_BUCKET_REFRESH_CHECK_INTERVAL);
       command->setTaskQueue(taskQueue.get());
       command->setRoutingTable(routingTable.get());
       command->setTaskFactory(taskFactory.get());
       tempCommands.push_back(std::move(command));
     }
     {
-      auto command = make_unique<DHTPeerAnnounceCommand>
-        (e->newCUID(), e, DHT_PEER_ANNOUNCE_CHECK_INTERVAL);
+      auto command = make_unique<DHTPeerAnnounceCommand>(
+          e->newCUID(), e, DHT_PEER_ANNOUNCE_CHECK_INTERVAL);
       command->setPeerAnnounceStorage(peerAnnounceStorage.get());
       tempCommands.push_back(std::move(command));
     }
     {
-      auto command = make_unique<DHTAutoSaveCommand>
-        (e->newCUID(), e, family, 30*60);
+      auto command =
+          make_unique<DHTAutoSaveCommand>(e->newCUID(), e, family, 30_min);
       command->setLocalNode(localNode);
       command->setRoutingTable(routingTable.get());
       tempCommands.push_back(std::move(command));
     }
     // add deserialized nodes to routing table
     auto& desnodes = deserializer.getNodes();
-    for(auto& node : desnodes) {
+    for (auto& node : desnodes) {
       routingTable->addNode(node);
     }
-    if(!desnodes.empty()) {
-      auto task = std::static_pointer_cast<DHTBucketRefreshTask>
-        (taskFactory->createBucketRefreshTask());
+    if (!desnodes.empty()) {
+      auto task = std::static_pointer_cast<DHTBucketRefreshTask>(
+          taskFactory->createBucketRefreshTask());
       task->setForceRefresh(true);
       taskQueue->addPeriodicTask1(task);
     }
     // assign them into DHTRegistry
-    if(family == AF_INET) {
+    if (family == AF_INET) {
       DHTRegistry::getMutableData().localNode = localNode;
       DHTRegistry::getMutableData().routingTable = std::move(routingTable);
       DHTRegistry::getMutableData().taskQueue = std::move(taskQueue);
       DHTRegistry::getMutableData().taskFactory = std::move(taskFactory);
       DHTRegistry::getMutableData().peerAnnounceStorage =
-        std::move(peerAnnounceStorage);
+          std::move(peerAnnounceStorage);
       DHTRegistry::getMutableData().tokenTracker = std::move(tokenTracker);
       DHTRegistry::getMutableData().messageDispatcher = std::move(dispatcher);
       DHTRegistry::getMutableData().messageReceiver = std::move(receiver);
       DHTRegistry::getMutableData().messageFactory = std::move(factory);
       e->getBtRegistry()->setUDPTrackerClient(udpTrackerClient);
       DHTRegistry::setInitialized(true);
-    } else {
+    }
+    else {
       DHTRegistry::getMutableData6().localNode = localNode;
       DHTRegistry::getMutableData6().routingTable = std::move(routingTable);
       DHTRegistry::getMutableData6().taskQueue = std::move(taskQueue);
       DHTRegistry::getMutableData6().taskFactory = std::move(taskFactory);
       DHTRegistry::getMutableData6().peerAnnounceStorage =
-        std::move(peerAnnounceStorage);
+          std::move(peerAnnounceStorage);
       DHTRegistry::getMutableData6().tokenTracker = std::move(tokenTracker);
       DHTRegistry::getMutableData6().messageDispatcher = std::move(dispatcher);
       DHTRegistry::getMutableData6().messageReceiver = std::move(receiver);
       DHTRegistry::getMutableData6().messageFactory = std::move(factory);
       DHTRegistry::setInitialized6(true);
     }
-    if(e->getBtRegistry()->getUdpPort() == 0) {
+    if (e->getBtRegistry()->getUdpPort() == 0) {
       // We assign port last so that no exception gets in the way
       e->getBtRegistry()->setUdpPort(port);
     }
-  } catch(RecoverableException& ex) {
+  }
+  catch (RecoverableException& ex) {
     A2_LOG_ERROR_EX(fmt("Exception caught while initializing DHT functionality."
                         " DHT is disabled."),
                     ex);
     tempCommands.clear();
-    if(family == AF_INET) {
+    tempRoutineCommands.clear();
+    if (family == AF_INET) {
       DHTRegistry::clearData();
-      e->getBtRegistry()->setUDPTrackerClient
-        (std::shared_ptr<UDPTrackerClient>{});
-    } else {
+      e->getBtRegistry()->setUDPTrackerClient(
+          std::shared_ptr<UDPTrackerClient>{});
+    }
+    else {
       DHTRegistry::clearData6();
     }
   }
-  return tempCommands;
+  return std::make_pair(std::move(tempCommands),
+                        std::move(tempRoutineCommands));
 }
 
 } // namespace aria2
