@@ -40,15 +40,16 @@
 #include <string>
 #include <vector>
 
+#include <aria2/aria2.h>
 #include "a2time.h"
 
 namespace aria2 {
 
-struct TorrentAttribute:public ContextAttribute {
+struct TorrentAttribute : public ContextAttribute {
   std::string name;
-  std::string mode;
-  std::vector<std::vector<std::string> > announceList;
-  std::vector<std::pair<std::string, uint16_t> > nodes;
+  BtFileMode mode;
+  std::vector<std::vector<std::string>> announceList;
+  std::vector<std::pair<std::string, uint16_t>> nodes;
   // raw hash value 20 bytes.
   std::string infoHash;
   std::string metadata;
@@ -70,4 +71,3 @@ struct TorrentAttribute:public ContextAttribute {
 } // namespace aria2
 
 #endif // D_TORRENT_ATTRIBUTE_H
-
